@@ -170,7 +170,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.31'
+__version__ = '0.1.32'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -197,8 +197,9 @@ NodeFilesInfo = List[NodeFileInfo]              #: list of node file info tuples
 def check_item_id(item_id: str) -> str:
     """ check if the passed item id string is valid.
 
-    :param item_id:     item id to check.
-    :return:            "" if all chars in the passed item id are valid, else one of the translated message strings.
+    :param item_id:             item id to check.
+    :return:                    "" if all chars in the passed item id are valid,
+                                else one of the translated message strings.
     """
     msg = get_f_string("item id '{item_id}' ")
     if not isinstance(item_id, str):
@@ -217,8 +218,8 @@ def check_item_id(item_id: str) -> str:
 def correct_item_id(item_id: str) -> str:
     """ strip and replace extra/invalid characters from the passed item id string.
 
-    :param item_id:     item id string to correct.
-    :return:            corrected item id (can result in an empty string).
+    :param item_id:             item id string to correct.
+    :return:                    corrected item id (can result in an empty string).
     """
     item_id = item_id.replace(FLOW_PATH_TEXT_SEP, '/').strip().strip('@~*-#.,;:').strip()
     if item_id == FLOW_PATH_ROOT_ID:
@@ -226,11 +227,71 @@ def correct_item_id(item_id: str) -> str:
     return item_id.lstrip(INVALID_ITEM_ID_PREFIX_CHARS)
 
 
+def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
+    """ parse and interpret text block for (optional) flow path text and node data (in pprint.pformat/repr format).
+
+    :param text:                text block to be parsed. The text block can optionally be prefixed with a extra
+                                line (separated by a new line '\\n' character) containing the destination flow path
+                                in text format (using FLOW_PATH_TEXT_SEP to separate the flow path items).
+
+                                The (rest of the) text block represents the node/item data in one of the
+                                following formats:
+
+                                * single text line (interpreted as single leaf item).
+                                * multiple text lines (interpreted as multiple leaf items).
+                                * dict repr string (starting with '{' character).
+                                * list repr string (starting with '[' character).
+
+    :return:                    tuple of flow path (empty string if root or not given) and node list.
+    """
+    flow_path_text = ""
+    if text.startswith('{'):
+        node_lit = '[' + text + ']'
+    elif text.startswith('['):
+        node_lit = text
+    else:
+        parts = text.split("\n", maxsplit=1)
+        if len(parts) == 2 and parts[1].startswith(('[', '{')):
+            flow_path_text = parts[0]
+            node_lit = parts[1] if parts[1][0] == '[' else "[" + parts[1] + "]"
+        else:
+            node_lit = "[" + ",".join("{'id': '" + line + "'}" for line in text.split("\n") if line) + "]"
+
+    try:
+        node = ast.literal_eval(node_lit)
+    except (SyntaxError, ValueError):
+        node = []
+
+    return flow_path_text, node
+
+
+"""
+
+        item = ast.literal_eval(text)
+        print("=== sent item", item)
+        self.add_item(item)
+    elif "\n" in text:
+        print("=== sent flow path and node", text)
+        flow_path_text, node_literal = text.split("\n", maxsplit=1)
+        flow_path = self.flow_path_from_text(flow_path_text, skip_check=True)
+        print("    resulting flow_path:", flow_path)
+        node = ast.literal_eval(node_literal)
+        print("    resulting node:", node)
+        node_to_add_to = self.flow_path_node(flow_path, create=True)
+        self.add_items(node, node_to_add_to=node_to_add_to)
+    else:
+        item_id = text
+        print("=== sent item id", item_id)
+        self.add_item(dict(id=item_id))
+"""
+
+
 def item_sel_filter(item: LiszItem) -> bool:
     """ callable for to filter selected LiszItems.
 
-    :param item:        item data structure to check.
-    :return:            True if item is a selected leaf or if item is a node with only selected sub-leaves, else False.
+    :param item:                item data structure to check.
+    :return:                    True if item is a selected leaf or if item is a node with only selected sub-leaves,
+                                else False.
     """
     if 'node' in item:
         for sub_item in item['node']:
@@ -243,8 +304,9 @@ def item_sel_filter(item: LiszItem) -> bool:
 def item_unsel_filter(item: LiszItem) -> bool:
     """ callable for to filter unselected LiszItems.
 
-    :param item:        item data structure to check.
-    :return:            True if item is an unselected leaf or if item is a node with only unselected leaves, else False.
+    :param item:                item data structure to check.
+    :return:                    True if item is an unselected leaf or if item is a node with only unselected leaves,
+                                else False.
     """
     if 'node' in item:
         for sub_item in item['node']:
@@ -257,8 +319,8 @@ def item_unsel_filter(item: LiszItem) -> bool:
 def node_from_literal(lit: str) -> LiszNode:
     """ parse passed string for to integrate/add them into the current displayed node or item.
 
-    :param lit:             item/node data in string representation format.
-    :return:                LiszNode list of parsed LiszItem items.
+    :param lit:                 item/node data in string representation format.
+    :return:                    LiszNode list of parsed LiszItem items.
     """
     if lit.startswith('['):
         try:
@@ -504,7 +566,7 @@ class LiszDataMixin(ABC):
             # the alternative `os.makedirs(exist_ok=True)` has problems on POSIX with '..' in the path
             pathlib.Path(file_path).mkdir(parents=True, exist_ok=True)
             with open(os.path.join(file_path, file_name), 'w') as file_handle:
-                file_handle.write(repr(node))
+                file_handle.write(pformat(node))
         except (FileExistsError, FileNotFoundError, OSError, ValueError) as ex:
             return ex
         return None
@@ -1038,7 +1100,7 @@ class LiszDataMixin(ABC):
         self.shrink_node_size(extract_node, item_filter=extract_filter, recursive=recursive)
 
         if extract_action in ('copy', 'cut'):
-            self.call_method('on_clipboard_key_c', repr(extract_node))  # Clipboard.copy(repr(node))
+            self.call_method('on_clipboard_key_c', pformat(extract_node))  # Clipboard.copy(repr(node))
         elif extract_action == 'export':
             self.export_node(flow_path, file_path=event_kwargs.get('export_path', '.'), node=extract_node)
         elif extract_action == 'share':
